class NoKey(Exception):
    pass

class Not200(Exception):
    pass